#############
API Reference
#############

.. toctree::
    :maxdepth: 2

    project.rst
    partitions.rst
    blueprint.rst
    model.rst
    job.rst
    modeljob.rst
    prediction_dataset.rst
    predict_job.rst
    featurelist.rst
    feature.rst
    prime.rst
    advanced_options.rst
    imported_model.rst
